=================
Django Model Mail
=================


.. image:: https://img.shields.io/pypi/v/django-model-mail.svg
        :target: https://pypi.python.org/pypi/django-model-mail

.. image:: https://img.shields.io/travis/la1t/django-model-mail.svg
        :target: https://travis-ci.org/la1t/django-model-mail


Django package that helps to create emails from models (e.g. for admins' notifications)


* Free software: MIT license


Features
--------

* TODO


Deploying
---------

A reminder for the maintainers on how to deploy.
Make sure all your changes are committed (including an entry in HISTORY.rst).
Then run::

$ poetry version patch # possible: major / minor / patch
$ git push
$ git push --tags

Travis will then deploy to PyPI if tests pass.
